# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

### 🚀 Features

- Add s3 support on cli (table-version)

### 🐛 Bug Fixes

- Remove logs for cli runner's sake
- Add condition on table_type for cli

<!-- generated by git-cliff -->
